# Table of Contents

- [application-portfolio-assessment-enrich-data](<./application-portfolio-assessment-enrich-data.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 2: Collect and Maintain Data](<./Step-2-Collect-and-Maintain-Data.md>)
